Crate hydro2_3p Copy item path Source pub use rand ;pub use serde_json ;pub use tokio ;pub use futures ;colored Coloring terminal so simple, you already know how to do it ! de Generic data structure deserialization framework. fs Asynchronous file utilities. io Traits, helpers, and type definitions for asynchronous I/O functionality. mpsc A multi-producer, single-consumer queue for sending values between
asynchronous tasks. oneshot A one-shot channel is used for sending a single message between
asynchronous tasks. The channel function is used to create a
Sender and Receiver handle pair that form the channel. thread Native threads. arc debug Constructs an event at the debug level. error Constructs an event at the error level. error_tree info Constructs an event at the info level. ix json Construct a serde_json::Value from a JSON literal. lazy_static name Macro to create a name with an optional separator. setup_test_logger warn Constructs an event at the warn level. x xp Arc A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically
Reference Counted’. AssertUnwindSafe A simple wrapper around a type to assert that it is unwind safe. AsyncMutex An asynchronous Mutex-like type. AsyncRwLock An asynchronous reader-writer lock. AsyncRwLockReadGuard RAII structure used to release the shared read access of a lock when
dropped. AsyncRwLockWriteGuard RAII structure used to release the exclusive write access of a lock when
dropped. AtomicI32 An integer type which can be safely shared between threads. AtomicUsize An integer type which can be safely shared between threads. BufReader The BufReader struct adds buffering to any reader. BufWriter Wraps a writer and buffers its output. BufferedLayer BufferedSubscriberLayer Chars An iterator over the char s of a string slice. Chunks An iterator over a slice in (non-overlapping) chunks (chunk_size elements at a
time), starting at the beginning of the slice. Duration A Duration type to represent a span of time, typically used for system
timeouts. Enumerate An iterator that yields the current count and the element during iteration. File A reference to an open file on the filesystem. FileLoggingConfiguration Formatter Configuration for formatting. HashMap A hash map implemented with quadratic probing and SIMD lookup. HashSet A hash set implemented as a HashMap where the value is (). Instant A measurement of a monotonically nondecreasing clock.
Opaque and useful only with Duration. JoinHandle An owned permission to join on a task (await its termination). JoinSet A collection of tasks spawned on a Tokio runtime. NameValidator Validator struct to validate names using a regular expression. OwnedSemaphorePermit An owned permit from the semaphore. Path A slice of a path (akin to str ). PathBuf An owned, mutable path (akin to String ). Peekable An iterator with a peek() that returns an optional reference to the next
element. PhantomData Zero-sized type used to mark things that “act like” they own a T. Rc A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference
Counted’. Receiver Receives values from the associated Sender. RefCell A mutable memory location with dynamically checked borrow rules Scope A scope to spawn scoped threads in. ScopedJoinHandle An owned permission to join on a scoped thread (block on its termination). Semaphore Counting semaphore performing asynchronous permit acquisition. Sender Sends values to the associated Receiver. StdMutex A mutual exclusion primitive useful for protecting shared data TokioRuntime The Tokio runtime. UniqueNameEnforcer Trait for ensuring unique names across a collection or context. VecDeque A double-ended queue implemented with a growable ring buffer. AtomicOrdering Atomic memory orderings Cow A clone-on-write smart pointer. EventPrinter JsonValue Represents any valid JSON value. LogLevel NameError Custom error type for handling name-related issues. Ordering An Ordering is the result of a comparison between two values. TrySendError This enumeration is the list of the possible error outcomes for the
try_send method. Value Represents any valid JSON value. AsyncBufReadExt An extension trait which adds utility methods to AsyncBufRead types. AsyncWriteExt Writes bytes to a sink. BufRead A BufRead is a type of Reader which has an internal buffer, allowing it
to perform extra ways of reading. BufferedSubscriber Debug ? formatting.DefaultName Trait for providing a default name. Deref Used for immutable dereferencing operations, like *v. Deserialize A data structure that can be deserialized from any data format supported
by Serde. Deserializer A data format that can deserialize any data structure supported by
Serde. Display Format trait for an empty format, {}. Error Error is a trait representing the basic expectations for error values,
i.e., values of type E in Result<T, E> .Flushable FromStr Parse a value from a string LazyStatic Support trait for enabling a few common operation on lazy static values. MultilingualName Trait for supporting names in multiple languages. NameHistory Provides a history of names an item has had. Named Trait for getting the name of an item. NamedAlias Trait for handling multiple names or aliases. NamespaceName Trait for namespacing names. NormalizeName Trait for normalizing the case of a name (e.g., lowercase). ResetName Trait for resetting the name of an item to its default. Serialize A data structure that can be serialized into any data format supported
by Serde. Serializer A data format that can serialize any data structure supported by Serde. SetName Trait for setting the name of an item with error handling. SetNameWithHistory Trait for setting the name while maintaining a history of changes. ValidateName Trait for validating a name, returning a Result. Write A trait for objects which are byte-oriented sinks. Zero Defines an additive identity element for Self. __Deref Used for immutable dereferencing operations, like *v. block_on Run a future to completion on the current thread. catch_unwind Invokes a closure, capturing the cause of an unwinding panic if one occurs. channel Creates a bounded mpsc channel for communicating between asynchronous tasks
with backpressure. configure_tracing Initializes the logging subscriber. create_file_logging_subscriber init_default_file_logging init_file_logging init_test_logger init_test_logger_with_max_level_filter initialize Takes a shared reference to a lazy static and initializes
it if it has not been already. join_all Creates a future which represents a collection of the outputs of the futures
given. setup_buffered_tracing setup_default_buffered_tracing setup_dynamic_tracing sleep Waits until duration has elapsed. FmtResult The type returned by formatter methods. async_trait disable traced_test Builder Create a builder struct for the deriving struct. CloneGetters CopyGetters Debug Derive macro generating an impl of the trait Debug. Deserialize Getters MutGetters NamedItem The attribute macro to derive Named, DefaultName, SetName, etc. behaviors. Serialize Setters WithSetters